# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20026ResponseDisks(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'disk_type': 'str',
        'disk_uuid': 'str',
        'storage_node': 'str',
        'vpartition_id': 'int',
        'raid_group_name': 'str',
        'usage': 'str',
        'status': 'str',
        'capacity': 'int',
        'allocation_group': 'str',
        'cache': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'disk_type': 'disk_type',
        'disk_uuid': 'disk_uuid',
        'storage_node': 'storage_node',
        'vpartition_id': 'vpartition_id',
        'raid_group_name': 'raid_group_name',
        'usage': 'usage',
        'status': 'status',
        'capacity': 'capacity',
        'allocation_group': 'allocation_group',
        'cache': 'cache',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, disk_type=None, disk_uuid=None, storage_node=None, vpartition_id=None, raid_group_name=None, usage=None, status=None, capacity=None, allocation_group=None, cache=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20026ResponseDisks - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._disk_type = None
        self._disk_uuid = None
        self._storage_node = None
        self._vpartition_id = None
        self._raid_group_name = None
        self._usage = None
        self._status = None
        self._capacity = None
        self._allocation_group = None
        self._cache = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if disk_type is not None:
            self.disk_type = disk_type
        if disk_uuid is not None:
            self.disk_uuid = disk_uuid
        if storage_node is not None:
            self.storage_node = storage_node
        if vpartition_id is not None:
            self.vpartition_id = vpartition_id
        if raid_group_name is not None:
            self.raid_group_name = raid_group_name
        if usage is not None:
            self.usage = usage
        if status is not None:
            self.status = status
        if capacity is not None:
            self.capacity = capacity
        if allocation_group is not None:
            self.allocation_group = allocation_group
        if cache is not None:
            self.cache = cache
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20026ResponseDisks.


        :param name: The name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The display_name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20026ResponseDisks.


        :param display_name: The display_name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def disk_type(self):
        """Gets the disk_type of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The disk_type of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._disk_type

    @disk_type.setter
    def disk_type(self, disk_type):
        """Sets the disk_type of this InlineResponse20026ResponseDisks.


        :param disk_type: The disk_type of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._disk_type = disk_type

    @property
    def disk_uuid(self):
        """Gets the disk_uuid of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The disk_uuid of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._disk_uuid

    @disk_uuid.setter
    def disk_uuid(self, disk_uuid):
        """Sets the disk_uuid of this InlineResponse20026ResponseDisks.


        :param disk_uuid: The disk_uuid of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._disk_uuid = disk_uuid

    @property
    def storage_node(self):
        """Gets the storage_node of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The storage_node of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._storage_node

    @storage_node.setter
    def storage_node(self, storage_node):
        """Sets the storage_node of this InlineResponse20026ResponseDisks.


        :param storage_node: The storage_node of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._storage_node = storage_node

    @property
    def vpartition_id(self):
        """Gets the vpartition_id of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The vpartition_id of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: int
        """
        return self._vpartition_id

    @vpartition_id.setter
    def vpartition_id(self, vpartition_id):
        """Sets the vpartition_id of this InlineResponse20026ResponseDisks.


        :param vpartition_id: The vpartition_id of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: int
        """

        self._vpartition_id = vpartition_id

    @property
    def raid_group_name(self):
        """Gets the raid_group_name of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The raid_group_name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._raid_group_name

    @raid_group_name.setter
    def raid_group_name(self, raid_group_name):
        """Sets the raid_group_name of this InlineResponse20026ResponseDisks.


        :param raid_group_name: The raid_group_name of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._raid_group_name = raid_group_name

    @property
    def usage(self):
        """Gets the usage of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The usage of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """Sets the usage of this InlineResponse20026ResponseDisks.


        :param usage: The usage of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._usage = usage

    @property
    def status(self):
        """Gets the status of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The status of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20026ResponseDisks.


        :param status: The status of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The capacity of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse20026ResponseDisks.


        :param capacity: The capacity of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def allocation_group(self):
        """Gets the allocation_group of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The allocation_group of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._allocation_group

    @allocation_group.setter
    def allocation_group(self, allocation_group):
        """Sets the allocation_group of this InlineResponse20026ResponseDisks.


        :param allocation_group: The allocation_group of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._allocation_group = allocation_group

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The cache of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20026ResponseDisks.


        :param cache: The cache of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._cache = cache

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The created_at of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20026ResponseDisks.


        :param created_at: The created_at of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20026ResponseDisks.  # noqa: E501


        :return: The modified_at of this InlineResponse20026ResponseDisks.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20026ResponseDisks.


        :param modified_at: The modified_at of this InlineResponse20026ResponseDisks.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20026ResponseDisks, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20026ResponseDisks):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20026ResponseDisks):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from Zios.api.accounts_api import AccountsApi
from Zios.api.drives_api import DrivesApi
from Zios.api.load_balancer_api import LoadBalancerApi
from Zios.api.logs_api import LogsApi
from Zios.api.object_storage_destinations_api import ObjectStorageDestinationsApi
from Zios.api.roles_api import RolesApi
from Zios.api.settings_api import SettingsApi
from Zios.api.storage_policies_api import StoragePoliciesApi
from Zios.api.usage_reports_api import UsageReportsApi
from Zios.api.users_api import UsersApi
from Zios.api.virtual_controllers_api import VirtualControllersApi



# coding: utf-8

# flake8: noqa

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from ProvisioningPortal.api.authentication_api import AuthenticationApi
from ProvisioningPortal.api.billing_api import BillingApi
from ProvisioningPortal.api.cloud_api import CloudApi
from ProvisioningPortal.api.compute_api import ComputeApi
from ProvisioningPortal.api.prices_api import PricesApi
from ProvisioningPortal.api.providers_api import ProvidersApi
from ProvisioningPortal.api.settings_api import SettingsApi
from ProvisioningPortal.api.tenant_api import TenantApi
from ProvisioningPortal.api.vpsa_api import VPSAApi
from ProvisioningPortal.api.virtual_network_api import VirtualNetworkApi
from ProvisioningPortal.api.vlan_api import VlanApi
from ProvisioningPortal.api.vpsa_requests_api import VpsaRequestsApi

# import ApiClient
from ProvisioningPortal.api_client import ApiClient
from ProvisioningPortal.configuration import Configuration
# import models into sdk package
from ProvisioningPortal.models.add_proxy_vc_to_vpsa_object_storage import AddProxyVcToVpsaObjectStorage
from ProvisioningPortal.models.add_storage_policy_to_vpsa_object_storage import AddStoragePolicyToVpsaObjectStorage
from ProvisioningPortal.models.add_storage_to_vpsa import AddStorageToVpsa
from ProvisioningPortal.models.add_virtual_network_vpsa import AddVirtualNetworkVpsa
from ProvisioningPortal.models.alloacate_vlan import AlloacateVlan
from ProvisioningPortal.models.approve import Approve
from ProvisioningPortal.models.change_vpsa_flash_cache_capacity import ChangeVpsaFlashCacheCapacity
from ProvisioningPortal.models.change_vpsa_zadara_engine import ChangeVpsaZadaraEngine
from ProvisioningPortal.models.create_cloud import CreateCloud
from ProvisioningPortal.models.create_compute_account import CreateComputeAccount
from ProvisioningPortal.models.create_object_storage_account import CreateObjectStorageAccount
from ProvisioningPortal.models.create_provider import CreateProvider
from ProvisioningPortal.models.create_provider_group import CreateProviderGroup
from ProvisioningPortal.models.create_virtual_network import CreateVirtualNetwork
from ProvisioningPortal.models.create_vpsa import CreateVpsa
from ProvisioningPortal.models.deallocate_vlan import DeallocateVlan
from ProvisioningPortal.models.default import Default
from ProvisioningPortal.models.default_response import DefaultResponse
from ProvisioningPortal.models.delete_virtual_networks import DeleteVirtualNetworks
from ProvisioningPortal.models.deny import Deny
from ProvisioningPortal.models.enable_object_account import EnableObjectAccount
from ProvisioningPortal.models.error import Error
from ProvisioningPortal.models.get_authentication_token import GetAuthenticationToken
from ProvisioningPortal.models.inline_response200 import InlineResponse200
from ProvisioningPortal.models.inline_response2001 import InlineResponse2001
from ProvisioningPortal.models.inline_response20010 import InlineResponse20010
from ProvisioningPortal.models.inline_response20010_data import InlineResponse20010Data
from ProvisioningPortal.models.inline_response20010_data_provider_groups import InlineResponse20010DataProviderGroups
from ProvisioningPortal.models.inline_response20011 import InlineResponse20011
from ProvisioningPortal.models.inline_response20011_data import InlineResponse20011Data
from ProvisioningPortal.models.inline_response20012 import InlineResponse20012
from ProvisioningPortal.models.inline_response20012_data import InlineResponse20012Data
from ProvisioningPortal.models.inline_response20013 import InlineResponse20013
from ProvisioningPortal.models.inline_response20014 import InlineResponse20014
from ProvisioningPortal.models.inline_response20014_data import InlineResponse20014Data
from ProvisioningPortal.models.inline_response20015 import InlineResponse20015
from ProvisioningPortal.models.inline_response20015_data import InlineResponse20015Data
from ProvisioningPortal.models.inline_response20016 import InlineResponse20016
from ProvisioningPortal.models.inline_response20017 import InlineResponse20017
from ProvisioningPortal.models.inline_response20018 import InlineResponse20018
from ProvisioningPortal.models.inline_response20018_data import InlineResponse20018Data
from ProvisioningPortal.models.inline_response20019 import InlineResponse20019
from ProvisioningPortal.models.inline_response2001_app_engines import InlineResponse2001AppEngines
from ProvisioningPortal.models.inline_response2001_cache import InlineResponse2001Cache
from ProvisioningPortal.models.inline_response2001_data import InlineResponse2001Data
from ProvisioningPortal.models.inline_response2001_drive_types import InlineResponse2001DriveTypes
from ProvisioningPortal.models.inline_response2001_engine_types import InlineResponse2001EngineTypes
from ProvisioningPortal.models.inline_response2001_fibre_channel import InlineResponse2001FibreChannel
from ProvisioningPortal.models.inline_response2001_flash_cache import InlineResponse2001FlashCache
from ProvisioningPortal.models.inline_response2001_vpsazone_group_storage_policy_types import InlineResponse2001VpsazoneGroupStoragePolicyTypes
from ProvisioningPortal.models.inline_response2001_zones import InlineResponse2001Zones
from ProvisioningPortal.models.inline_response2002 import InlineResponse2002
from ProvisioningPortal.models.inline_response20020 import InlineResponse20020
from ProvisioningPortal.models.inline_response20021 import InlineResponse20021
from ProvisioningPortal.models.inline_response20022 import InlineResponse20022
from ProvisioningPortal.models.inline_response20022_data import InlineResponse20022Data
from ProvisioningPortal.models.inline_response20023 import InlineResponse20023
from ProvisioningPortal.models.inline_response20024 import InlineResponse20024
from ProvisioningPortal.models.inline_response20024_data import InlineResponse20024Data
from ProvisioningPortal.models.inline_response20025 import InlineResponse20025
from ProvisioningPortal.models.inline_response20025_app_engine import InlineResponse20025AppEngine
from ProvisioningPortal.models.inline_response20025_cache import InlineResponse20025Cache
from ProvisioningPortal.models.inline_response20025_data import InlineResponse20025Data
from ProvisioningPortal.models.inline_response20025_drives import InlineResponse20025Drives
from ProvisioningPortal.models.inline_response20025_engine import InlineResponse20025Engine
from ProvisioningPortal.models.inline_response20025_provider import InlineResponse20025Provider
from ProvisioningPortal.models.inline_response20026 import InlineResponse20026
from ProvisioningPortal.models.inline_response20026_data import InlineResponse20026Data
from ProvisioningPortal.models.inline_response20026_data_cache import InlineResponse20026DataCache
from ProvisioningPortal.models.inline_response20027 import InlineResponse20027
from ProvisioningPortal.models.inline_response20027_data import InlineResponse20027Data
from ProvisioningPortal.models.inline_response20027_data_app_engine import InlineResponse20027DataAppEngine
from ProvisioningPortal.models.inline_response20027_data_engine import InlineResponse20027DataEngine
from ProvisioningPortal.models.inline_response20027_data_provider import InlineResponse20027DataProvider
from ProvisioningPortal.models.inline_response20027_data_publiczios import InlineResponse20027DataPubliczios
from ProvisioningPortal.models.inline_response20027_data_storage_policies import InlineResponse20027DataStoragePolicies
from ProvisioningPortal.models.inline_response20028 import InlineResponse20028
from ProvisioningPortal.models.inline_response20029 import InlineResponse20029
from ProvisioningPortal.models.inline_response2002_data import InlineResponse2002Data
from ProvisioningPortal.models.inline_response2003 import InlineResponse2003
from ProvisioningPortal.models.inline_response20030 import InlineResponse20030
from ProvisioningPortal.models.inline_response20031 import InlineResponse20031
from ProvisioningPortal.models.inline_response20032 import InlineResponse20032
from ProvisioningPortal.models.inline_response20033 import InlineResponse20033
from ProvisioningPortal.models.inline_response20034 import InlineResponse20034
from ProvisioningPortal.models.inline_response20035 import InlineResponse20035
from ProvisioningPortal.models.inline_response20036 import InlineResponse20036
from ProvisioningPortal.models.inline_response20037 import InlineResponse20037
from ProvisioningPortal.models.inline_response20038 import InlineResponse20038
from ProvisioningPortal.models.inline_response20038_data import InlineResponse20038Data
from ProvisioningPortal.models.inline_response20039 import InlineResponse20039
from ProvisioningPortal.models.inline_response2004 import InlineResponse2004
from ProvisioningPortal.models.inline_response20040 import InlineResponse20040
from ProvisioningPortal.models.inline_response20041 import InlineResponse20041
from ProvisioningPortal.models.inline_response20042 import InlineResponse20042
from ProvisioningPortal.models.inline_response20043 import InlineResponse20043
from ProvisioningPortal.models.inline_response20043_data import InlineResponse20043Data
from ProvisioningPortal.models.inline_response20044 import InlineResponse20044
from ProvisioningPortal.models.inline_response20045 import InlineResponse20045
from ProvisioningPortal.models.inline_response20046 import InlineResponse20046
from ProvisioningPortal.models.inline_response20047 import InlineResponse20047
from ProvisioningPortal.models.inline_response20047_data import InlineResponse20047Data
from ProvisioningPortal.models.inline_response20048 import InlineResponse20048
from ProvisioningPortal.models.inline_response20048_data import InlineResponse20048Data
from ProvisioningPortal.models.inline_response20049 import InlineResponse20049
from ProvisioningPortal.models.inline_response2005 import InlineResponse2005
from ProvisioningPortal.models.inline_response20050 import InlineResponse20050
from ProvisioningPortal.models.inline_response2006 import InlineResponse2006
from ProvisioningPortal.models.inline_response2006_data import InlineResponse2006Data
from ProvisioningPortal.models.inline_response2006_data_ioengines import InlineResponse2006DataIoengines
from ProvisioningPortal.models.inline_response2006_data_ioengines_provider9 import InlineResponse2006DataIoenginesProvider9
from ProvisioningPortal.models.inline_response2006_data_ioengines_provider9_data import InlineResponse2006DataIoenginesProvider9Data
from ProvisioningPortal.models.inline_response2006_data_ioengines_provider9_data_vsa_v2_baby_vf import InlineResponse2006DataIoenginesProvider9DataVsaV2BabyVf
from ProvisioningPortal.models.inline_response2007 import InlineResponse2007
from ProvisioningPortal.models.inline_response2007_data import InlineResponse2007Data
from ProvisioningPortal.models.inline_response2008 import InlineResponse2008
from ProvisioningPortal.models.inline_response2008_data import InlineResponse2008Data
from ProvisioningPortal.models.inline_response2009 import InlineResponse2009
from ProvisioningPortal.models.inline_response200_data import InlineResponse200Data
from ProvisioningPortal.models.maintenance_mode import MaintenanceMode
from ProvisioningPortal.models.remove_vni_from_vpsa import RemoveVniFromVpsa
from ProvisioningPortal.models.reset_authentication_token import ResetAuthenticationToken
from ProvisioningPortal.models.set_flavor_price import SetFlavorPrice
from ProvisioningPortal.models.set_log_level import SetLogLevel
from ProvisioningPortal.models.set_vlan_as_default import SetVlanAsDefault
from ProvisioningPortal.models.update_cloud import UpdateCloud
from ProvisioningPortal.models.update_object_account import UpdateObjectAccount
from ProvisioningPortal.models.update_provider import UpdateProvider
from ProvisioningPortal.models.update_provider_group import UpdateProviderGroup
from ProvisioningPortal.models.vpsas_json_drives import VpsasJsonDrives
from ProvisioningPortal.models.vpsasvpsa_iddrives_json_drives import VpsasvpsaIddrivesJsonDrives



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.storage_nodes_api import StorageNodesApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestStorageNodesApi(unittest.TestCase):
    """StorageNodesApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.storage_nodes_api.StorageNodesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_evacoate_vc_from_sn(self):
        """Test case for evacoate_vc_from_sn

        """
        pass

    def test_evacoated_drives_from_sn(self):
        """Test case for evacoated_drives_from_sn

        """
        pass

    def test_get_all_storage_nodes(self):
        """Test case for get_all_storage_nodes

        """
        pass

    def test_get_schedulable_services_status(self):
        """Test case for get_schedulable_services_status

        """
        pass

    def test_get_sn_cache_partitions_details(self):
        """Test case for get_sn_cache_partitions_details

        """
        pass

    def test_get_sn_conf(self):
        """Test case for get_sn_conf

        """
        pass

    def test_get_sn_vcs_details(self):
        """Test case for get_sn_vcs_details

        """
        pass

    def test_get_storage_node(self):
        """Test case for get_storage_node

        """
        pass

    def test_get_storage_node_drives(self):
        """Test case for get_storage_node_drives

        """
        pass

    def test_import_sn_new_drives(self):
        """Test case for import_sn_new_drives

        """
        pass

    def test_install_sn(self):
        """Test case for install_sn

        """
        pass

    def test_license_storage_node(self):
        """Test case for license_storage_node

        """
        pass

    def test_reboot_storage_node(self):
        """Test case for reboot_storage_node

        """
        pass

    def test_refresh_sn_license_status(self):
        """Test case for refresh_sn_license_status

        """
        pass

    def test_set_scheduling_status(self):
        """Test case for set_scheduling_status

        """
        pass

    def test_shutdown_storage_node(self):
        """Test case for shutdown_storage_node

        """
        pass

    def test_upgrade_sn(self):
        """Test case for upgrade_sn

        """
        pass

    def test_upgrade_sn_megaraid_and_drives_firmware(self):
        """Test case for upgrade_sn_megaraid_and_drives_firmware

        """
        pass

    def test_zsnap_storage_node(self):
        """Test case for zsnap_storage_node

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200193Response(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'message': 'str',
        'name': 'str',
        'uuid': 'str',
        'cloud_uuid': 'str',
        'url': 'str',
        'display_name': 'str',
        'version': 'str',
        'enterprise_suite': 'str',
        'language': 'str',
        'smb_ads': 'str',
        'cpu_usage_alert': 'int',
        'mem_usage_alert': 'int',
        'cpu_docker_usage_alert': 'int',
        'mem_docker_usage_alert': 'int',
        'multi_zone': 'str',
        'afa': 'str',
        'io_engine': 'str',
        'io_vcpus': 'int',
        'io_ram_mb': 'int',
        'app_engine': 'str',
        'app_vcpus': 'int',
        'app_ram_mb': 'int',
        'wwnn': 'str',
        'smb_netbios_name': 'str',
        'defrag_enable': 'str',
        'defrag_runtime': 'str',
        'defrag_active': 'str',
        'defrag_volumes_processed': 'str',
        'defrag_volumes_pending': 'str',
        'defrag_elapsed_time_sec': 'str',
        'base_cache_gb': 'int',
        'ext_cache_gb': 'int',
        'last_vpsa_request': 'str',
        'vpsa_request_status': 'str',
        'pool_types_count': 'int',
        'pool_types': 'list[str]',
        'smb_charset_count': 'int',
        'smb_charsets': 'list[str]',
        'admin_access_enabled': 'str',
        'is_support_privilege_access_enabled': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'service_mode': 'str',
        'expire_password': 'str',
        'expire_password_after': 'str',
        'min_password_length': 'str',
        'password_must_contain_letters': 'str',
        'password_must_contain_numbers': 'str',
        'password_must_contain_uppercase_letters': 'str',
        'password_must_contain_special_characters': 'str',
        'password_requirements_text': 'str',
        'password_history': 'str',
        'legacy_otp_secret': 'str',
        'vpsa_chap_user': 'str',
        'vpsa_chap_secret': 'str'
    }

    attribute_map = {
        'message': 'message',
        'name': 'name',
        'uuid': 'uuid',
        'cloud_uuid': 'CloudUuid',
        'url': 'url',
        'display_name': 'display_name',
        'version': 'version',
        'enterprise_suite': 'enterprise_suite',
        'language': 'language',
        'smb_ads': 'smb_ads',
        'cpu_usage_alert': 'cpu_usage_alert',
        'mem_usage_alert': 'mem_usage_alert',
        'cpu_docker_usage_alert': 'cpu_docker_usage_alert',
        'mem_docker_usage_alert': 'mem_docker_usage_alert',
        'multi_zone': 'multi-zone',
        'afa': 'afa',
        'io_engine': 'io_engine',
        'io_vcpus': 'io_vcpus',
        'io_ram_mb': 'io_ram_mb',
        'app_engine': 'app_engine',
        'app_vcpus': 'app_vcpus',
        'app_ram_mb': 'app_ram_mb',
        'wwnn': 'wwnn',
        'smb_netbios_name': 'smb_netbios_name',
        'defrag_enable': 'defrag_enable',
        'defrag_runtime': 'defrag_runtime',
        'defrag_active': 'defrag_active',
        'defrag_volumes_processed': 'defrag_volumes_processed',
        'defrag_volumes_pending': 'defrag_volumes_pending',
        'defrag_elapsed_time_sec': 'defrag_elapsed_time_sec',
        'base_cache_gb': 'base_cache_gb',
        'ext_cache_gb': 'ext_cache_gb',
        'last_vpsa_request': 'last_vpsa_request',
        'vpsa_request_status': 'vpsa_request_status',
        'pool_types_count': 'pool_types_count',
        'pool_types': 'pool_types',
        'smb_charset_count': 'smb_charset_count',
        'smb_charsets': 'smb_charsets',
        'admin_access_enabled': 'admin_access_enabled',
        'is_support_privilege_access_enabled': 'is_support_privilege_access_enabled',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'service_mode': 'service_mode',
        'expire_password': 'expire_password',
        'expire_password_after': 'expire_password_after',
        'min_password_length': 'min_password_length',
        'password_must_contain_letters': 'password_must_contain_letters',
        'password_must_contain_numbers': 'password_must_contain_numbers',
        'password_must_contain_uppercase_letters': 'password_must_contain_uppercase_letters',
        'password_must_contain_special_characters': 'password_must_contain_special_characters',
        'password_requirements_text': 'password_requirements_text',
        'password_history': 'password_history',
        'legacy_otp_secret': 'legacy_otp_secret',
        'vpsa_chap_user': 'vpsa_chap_user',
        'vpsa_chap_secret': 'vpsa_chap_secret'
    }

    def __init__(self, message=None, name=None, uuid=None, cloud_uuid=None, url=None, display_name=None, version=None, enterprise_suite=None, language=None, smb_ads=None, cpu_usage_alert=None, mem_usage_alert=None, cpu_docker_usage_alert=None, mem_docker_usage_alert=None, multi_zone=None, afa=None, io_engine=None, io_vcpus=None, io_ram_mb=None, app_engine=None, app_vcpus=None, app_ram_mb=None, wwnn=None, smb_netbios_name=None, defrag_enable=None, defrag_runtime=None, defrag_active=None, defrag_volumes_processed=None, defrag_volumes_pending=None, defrag_elapsed_time_sec=None, base_cache_gb=None, ext_cache_gb=None, last_vpsa_request=None, vpsa_request_status=None, pool_types_count=None, pool_types=None, smb_charset_count=None, smb_charsets=None, admin_access_enabled=None, is_support_privilege_access_enabled=None, created_at=None, modified_at=None, service_mode=None, expire_password=None, expire_password_after=None, min_password_length=None, password_must_contain_letters=None, password_must_contain_numbers=None, password_must_contain_uppercase_letters=None, password_must_contain_special_characters=None, password_requirements_text=None, password_history=None, legacy_otp_secret=None, vpsa_chap_user=None, vpsa_chap_secret=None, _configuration=None):  # noqa: E501
        """InlineResponse200193Response - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._message = None
        self._name = None
        self._uuid = None
        self._cloud_uuid = None
        self._url = None
        self._display_name = None
        self._version = None
        self._enterprise_suite = None
        self._language = None
        self._smb_ads = None
        self._cpu_usage_alert = None
        self._mem_usage_alert = None
        self._cpu_docker_usage_alert = None
        self._mem_docker_usage_alert = None
        self._multi_zone = None
        self._afa = None
        self._io_engine = None
        self._io_vcpus = None
        self._io_ram_mb = None
        self._app_engine = None
        self._app_vcpus = None
        self._app_ram_mb = None
        self._wwnn = None
        self._smb_netbios_name = None
        self._defrag_enable = None
        self._defrag_runtime = None
        self._defrag_active = None
        self._defrag_volumes_processed = None
        self._defrag_volumes_pending = None
        self._defrag_elapsed_time_sec = None
        self._base_cache_gb = None
        self._ext_cache_gb = None
        self._last_vpsa_request = None
        self._vpsa_request_status = None
        self._pool_types_count = None
        self._pool_types = None
        self._smb_charset_count = None
        self._smb_charsets = None
        self._admin_access_enabled = None
        self._is_support_privilege_access_enabled = None
        self._created_at = None
        self._modified_at = None
        self._service_mode = None
        self._expire_password = None
        self._expire_password_after = None
        self._min_password_length = None
        self._password_must_contain_letters = None
        self._password_must_contain_numbers = None
        self._password_must_contain_uppercase_letters = None
        self._password_must_contain_special_characters = None
        self._password_requirements_text = None
        self._password_history = None
        self._legacy_otp_secret = None
        self._vpsa_chap_user = None
        self._vpsa_chap_secret = None
        self.discriminator = None

        if message is not None:
            self.message = message
        if name is not None:
            self.name = name
        if uuid is not None:
            self.uuid = uuid
        if cloud_uuid is not None:
            self.cloud_uuid = cloud_uuid
        if url is not None:
            self.url = url
        if display_name is not None:
            self.display_name = display_name
        if version is not None:
            self.version = version
        if enterprise_suite is not None:
            self.enterprise_suite = enterprise_suite
        if language is not None:
            self.language = language
        if smb_ads is not None:
            self.smb_ads = smb_ads
        if cpu_usage_alert is not None:
            self.cpu_usage_alert = cpu_usage_alert
        if mem_usage_alert is not None:
            self.mem_usage_alert = mem_usage_alert
        if cpu_docker_usage_alert is not None:
            self.cpu_docker_usage_alert = cpu_docker_usage_alert
        if mem_docker_usage_alert is not None:
            self.mem_docker_usage_alert = mem_docker_usage_alert
        if multi_zone is not None:
            self.multi_zone = multi_zone
        if afa is not None:
            self.afa = afa
        if io_engine is not None:
            self.io_engine = io_engine
        if io_vcpus is not None:
            self.io_vcpus = io_vcpus
        if io_ram_mb is not None:
            self.io_ram_mb = io_ram_mb
        if app_engine is not None:
            self.app_engine = app_engine
        if app_vcpus is not None:
            self.app_vcpus = app_vcpus
        if app_ram_mb is not None:
            self.app_ram_mb = app_ram_mb
        if wwnn is not None:
            self.wwnn = wwnn
        if smb_netbios_name is not None:
            self.smb_netbios_name = smb_netbios_name
        if defrag_enable is not None:
            self.defrag_enable = defrag_enable
        if defrag_runtime is not None:
            self.defrag_runtime = defrag_runtime
        if defrag_active is not None:
            self.defrag_active = defrag_active
        if defrag_volumes_processed is not None:
            self.defrag_volumes_processed = defrag_volumes_processed
        if defrag_volumes_pending is not None:
            self.defrag_volumes_pending = defrag_volumes_pending
        if defrag_elapsed_time_sec is not None:
            self.defrag_elapsed_time_sec = defrag_elapsed_time_sec
        if base_cache_gb is not None:
            self.base_cache_gb = base_cache_gb
        if ext_cache_gb is not None:
            self.ext_cache_gb = ext_cache_gb
        if last_vpsa_request is not None:
            self.last_vpsa_request = last_vpsa_request
        if vpsa_request_status is not None:
            self.vpsa_request_status = vpsa_request_status
        if pool_types_count is not None:
            self.pool_types_count = pool_types_count
        if pool_types is not None:
            self.pool_types = pool_types
        if smb_charset_count is not None:
            self.smb_charset_count = smb_charset_count
        if smb_charsets is not None:
            self.smb_charsets = smb_charsets
        if admin_access_enabled is not None:
            self.admin_access_enabled = admin_access_enabled
        if is_support_privilege_access_enabled is not None:
            self.is_support_privilege_access_enabled = is_support_privilege_access_enabled
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if service_mode is not None:
            self.service_mode = service_mode
        if expire_password is not None:
            self.expire_password = expire_password
        if expire_password_after is not None:
            self.expire_password_after = expire_password_after
        if min_password_length is not None:
            self.min_password_length = min_password_length
        if password_must_contain_letters is not None:
            self.password_must_contain_letters = password_must_contain_letters
        if password_must_contain_numbers is not None:
            self.password_must_contain_numbers = password_must_contain_numbers
        if password_must_contain_uppercase_letters is not None:
            self.password_must_contain_uppercase_letters = password_must_contain_uppercase_letters
        if password_must_contain_special_characters is not None:
            self.password_must_contain_special_characters = password_must_contain_special_characters
        if password_requirements_text is not None:
            self.password_requirements_text = password_requirements_text
        if password_history is not None:
            self.password_history = password_history
        if legacy_otp_secret is not None:
            self.legacy_otp_secret = legacy_otp_secret
        if vpsa_chap_user is not None:
            self.vpsa_chap_user = vpsa_chap_user
        if vpsa_chap_secret is not None:
            self.vpsa_chap_secret = vpsa_chap_secret

    @property
    def message(self):
        """Gets the message of this InlineResponse200193Response.  # noqa: E501


        :return: The message of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this InlineResponse200193Response.


        :param message: The message of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def name(self):
        """Gets the name of this InlineResponse200193Response.  # noqa: E501


        :return: The name of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200193Response.


        :param name: The name of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def uuid(self):
        """Gets the uuid of this InlineResponse200193Response.  # noqa: E501


        :return: The uuid of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this InlineResponse200193Response.


        :param uuid: The uuid of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def cloud_uuid(self):
        """Gets the cloud_uuid of this InlineResponse200193Response.  # noqa: E501


        :return: The cloud_uuid of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._cloud_uuid

    @cloud_uuid.setter
    def cloud_uuid(self, cloud_uuid):
        """Sets the cloud_uuid of this InlineResponse200193Response.


        :param cloud_uuid: The cloud_uuid of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._cloud_uuid = cloud_uuid

    @property
    def url(self):
        """Gets the url of this InlineResponse200193Response.  # noqa: E501


        :return: The url of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this InlineResponse200193Response.


        :param url: The url of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200193Response.  # noqa: E501


        :return: The display_name of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200193Response.


        :param display_name: The display_name of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def version(self):
        """Gets the version of this InlineResponse200193Response.  # noqa: E501


        :return: The version of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InlineResponse200193Response.


        :param version: The version of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def enterprise_suite(self):
        """Gets the enterprise_suite of this InlineResponse200193Response.  # noqa: E501


        :return: The enterprise_suite of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._enterprise_suite

    @enterprise_suite.setter
    def enterprise_suite(self, enterprise_suite):
        """Sets the enterprise_suite of this InlineResponse200193Response.


        :param enterprise_suite: The enterprise_suite of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._enterprise_suite = enterprise_suite

    @property
    def language(self):
        """Gets the language of this InlineResponse200193Response.  # noqa: E501


        :return: The language of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this InlineResponse200193Response.


        :param language: The language of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def smb_ads(self):
        """Gets the smb_ads of this InlineResponse200193Response.  # noqa: E501


        :return: The smb_ads of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._smb_ads

    @smb_ads.setter
    def smb_ads(self, smb_ads):
        """Sets the smb_ads of this InlineResponse200193Response.


        :param smb_ads: The smb_ads of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._smb_ads = smb_ads

    @property
    def cpu_usage_alert(self):
        """Gets the cpu_usage_alert of this InlineResponse200193Response.  # noqa: E501


        :return: The cpu_usage_alert of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._cpu_usage_alert

    @cpu_usage_alert.setter
    def cpu_usage_alert(self, cpu_usage_alert):
        """Sets the cpu_usage_alert of this InlineResponse200193Response.


        :param cpu_usage_alert: The cpu_usage_alert of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._cpu_usage_alert = cpu_usage_alert

    @property
    def mem_usage_alert(self):
        """Gets the mem_usage_alert of this InlineResponse200193Response.  # noqa: E501


        :return: The mem_usage_alert of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._mem_usage_alert

    @mem_usage_alert.setter
    def mem_usage_alert(self, mem_usage_alert):
        """Sets the mem_usage_alert of this InlineResponse200193Response.


        :param mem_usage_alert: The mem_usage_alert of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._mem_usage_alert = mem_usage_alert

    @property
    def cpu_docker_usage_alert(self):
        """Gets the cpu_docker_usage_alert of this InlineResponse200193Response.  # noqa: E501


        :return: The cpu_docker_usage_alert of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._cpu_docker_usage_alert

    @cpu_docker_usage_alert.setter
    def cpu_docker_usage_alert(self, cpu_docker_usage_alert):
        """Sets the cpu_docker_usage_alert of this InlineResponse200193Response.


        :param cpu_docker_usage_alert: The cpu_docker_usage_alert of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._cpu_docker_usage_alert = cpu_docker_usage_alert

    @property
    def mem_docker_usage_alert(self):
        """Gets the mem_docker_usage_alert of this InlineResponse200193Response.  # noqa: E501


        :return: The mem_docker_usage_alert of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._mem_docker_usage_alert

    @mem_docker_usage_alert.setter
    def mem_docker_usage_alert(self, mem_docker_usage_alert):
        """Sets the mem_docker_usage_alert of this InlineResponse200193Response.


        :param mem_docker_usage_alert: The mem_docker_usage_alert of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._mem_docker_usage_alert = mem_docker_usage_alert

    @property
    def multi_zone(self):
        """Gets the multi_zone of this InlineResponse200193Response.  # noqa: E501


        :return: The multi_zone of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._multi_zone

    @multi_zone.setter
    def multi_zone(self, multi_zone):
        """Sets the multi_zone of this InlineResponse200193Response.


        :param multi_zone: The multi_zone of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._multi_zone = multi_zone

    @property
    def afa(self):
        """Gets the afa of this InlineResponse200193Response.  # noqa: E501


        :return: The afa of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._afa

    @afa.setter
    def afa(self, afa):
        """Sets the afa of this InlineResponse200193Response.


        :param afa: The afa of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._afa = afa

    @property
    def io_engine(self):
        """Gets the io_engine of this InlineResponse200193Response.  # noqa: E501


        :return: The io_engine of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._io_engine

    @io_engine.setter
    def io_engine(self, io_engine):
        """Sets the io_engine of this InlineResponse200193Response.


        :param io_engine: The io_engine of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._io_engine = io_engine

    @property
    def io_vcpus(self):
        """Gets the io_vcpus of this InlineResponse200193Response.  # noqa: E501


        :return: The io_vcpus of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._io_vcpus

    @io_vcpus.setter
    def io_vcpus(self, io_vcpus):
        """Sets the io_vcpus of this InlineResponse200193Response.


        :param io_vcpus: The io_vcpus of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._io_vcpus = io_vcpus

    @property
    def io_ram_mb(self):
        """Gets the io_ram_mb of this InlineResponse200193Response.  # noqa: E501


        :return: The io_ram_mb of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._io_ram_mb

    @io_ram_mb.setter
    def io_ram_mb(self, io_ram_mb):
        """Sets the io_ram_mb of this InlineResponse200193Response.


        :param io_ram_mb: The io_ram_mb of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._io_ram_mb = io_ram_mb

    @property
    def app_engine(self):
        """Gets the app_engine of this InlineResponse200193Response.  # noqa: E501


        :return: The app_engine of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._app_engine

    @app_engine.setter
    def app_engine(self, app_engine):
        """Sets the app_engine of this InlineResponse200193Response.


        :param app_engine: The app_engine of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._app_engine = app_engine

    @property
    def app_vcpus(self):
        """Gets the app_vcpus of this InlineResponse200193Response.  # noqa: E501


        :return: The app_vcpus of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._app_vcpus

    @app_vcpus.setter
    def app_vcpus(self, app_vcpus):
        """Sets the app_vcpus of this InlineResponse200193Response.


        :param app_vcpus: The app_vcpus of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._app_vcpus = app_vcpus

    @property
    def app_ram_mb(self):
        """Gets the app_ram_mb of this InlineResponse200193Response.  # noqa: E501


        :return: The app_ram_mb of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._app_ram_mb

    @app_ram_mb.setter
    def app_ram_mb(self, app_ram_mb):
        """Sets the app_ram_mb of this InlineResponse200193Response.


        :param app_ram_mb: The app_ram_mb of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._app_ram_mb = app_ram_mb

    @property
    def wwnn(self):
        """Gets the wwnn of this InlineResponse200193Response.  # noqa: E501


        :return: The wwnn of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._wwnn

    @wwnn.setter
    def wwnn(self, wwnn):
        """Sets the wwnn of this InlineResponse200193Response.


        :param wwnn: The wwnn of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._wwnn = wwnn

    @property
    def smb_netbios_name(self):
        """Gets the smb_netbios_name of this InlineResponse200193Response.  # noqa: E501


        :return: The smb_netbios_name of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._smb_netbios_name

    @smb_netbios_name.setter
    def smb_netbios_name(self, smb_netbios_name):
        """Sets the smb_netbios_name of this InlineResponse200193Response.


        :param smb_netbios_name: The smb_netbios_name of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._smb_netbios_name = smb_netbios_name

    @property
    def defrag_enable(self):
        """Gets the defrag_enable of this InlineResponse200193Response.  # noqa: E501


        :return: The defrag_enable of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._defrag_enable

    @defrag_enable.setter
    def defrag_enable(self, defrag_enable):
        """Sets the defrag_enable of this InlineResponse200193Response.


        :param defrag_enable: The defrag_enable of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._defrag_enable = defrag_enable

    @property
    def defrag_runtime(self):
        """Gets the defrag_runtime of this InlineResponse200193Response.  # noqa: E501


        :return: The defrag_runtime of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._defrag_runtime

    @defrag_runtime.setter
    def defrag_runtime(self, defrag_runtime):
        """Sets the defrag_runtime of this InlineResponse200193Response.


        :param defrag_runtime: The defrag_runtime of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._defrag_runtime = defrag_runtime

    @property
    def defrag_active(self):
        """Gets the defrag_active of this InlineResponse200193Response.  # noqa: E501


        :return: The defrag_active of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._defrag_active

    @defrag_active.setter
    def defrag_active(self, defrag_active):
        """Sets the defrag_active of this InlineResponse200193Response.


        :param defrag_active: The defrag_active of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._defrag_active = defrag_active

    @property
    def defrag_volumes_processed(self):
        """Gets the defrag_volumes_processed of this InlineResponse200193Response.  # noqa: E501


        :return: The defrag_volumes_processed of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._defrag_volumes_processed

    @defrag_volumes_processed.setter
    def defrag_volumes_processed(self, defrag_volumes_processed):
        """Sets the defrag_volumes_processed of this InlineResponse200193Response.


        :param defrag_volumes_processed: The defrag_volumes_processed of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._defrag_volumes_processed = defrag_volumes_processed

    @property
    def defrag_volumes_pending(self):
        """Gets the defrag_volumes_pending of this InlineResponse200193Response.  # noqa: E501


        :return: The defrag_volumes_pending of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._defrag_volumes_pending

    @defrag_volumes_pending.setter
    def defrag_volumes_pending(self, defrag_volumes_pending):
        """Sets the defrag_volumes_pending of this InlineResponse200193Response.


        :param defrag_volumes_pending: The defrag_volumes_pending of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._defrag_volumes_pending = defrag_volumes_pending

    @property
    def defrag_elapsed_time_sec(self):
        """Gets the defrag_elapsed_time_sec of this InlineResponse200193Response.  # noqa: E501


        :return: The defrag_elapsed_time_sec of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._defrag_elapsed_time_sec

    @defrag_elapsed_time_sec.setter
    def defrag_elapsed_time_sec(self, defrag_elapsed_time_sec):
        """Sets the defrag_elapsed_time_sec of this InlineResponse200193Response.


        :param defrag_elapsed_time_sec: The defrag_elapsed_time_sec of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._defrag_elapsed_time_sec = defrag_elapsed_time_sec

    @property
    def base_cache_gb(self):
        """Gets the base_cache_gb of this InlineResponse200193Response.  # noqa: E501


        :return: The base_cache_gb of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._base_cache_gb

    @base_cache_gb.setter
    def base_cache_gb(self, base_cache_gb):
        """Sets the base_cache_gb of this InlineResponse200193Response.


        :param base_cache_gb: The base_cache_gb of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._base_cache_gb = base_cache_gb

    @property
    def ext_cache_gb(self):
        """Gets the ext_cache_gb of this InlineResponse200193Response.  # noqa: E501


        :return: The ext_cache_gb of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._ext_cache_gb

    @ext_cache_gb.setter
    def ext_cache_gb(self, ext_cache_gb):
        """Sets the ext_cache_gb of this InlineResponse200193Response.


        :param ext_cache_gb: The ext_cache_gb of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._ext_cache_gb = ext_cache_gb

    @property
    def last_vpsa_request(self):
        """Gets the last_vpsa_request of this InlineResponse200193Response.  # noqa: E501


        :return: The last_vpsa_request of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._last_vpsa_request

    @last_vpsa_request.setter
    def last_vpsa_request(self, last_vpsa_request):
        """Sets the last_vpsa_request of this InlineResponse200193Response.


        :param last_vpsa_request: The last_vpsa_request of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._last_vpsa_request = last_vpsa_request

    @property
    def vpsa_request_status(self):
        """Gets the vpsa_request_status of this InlineResponse200193Response.  # noqa: E501


        :return: The vpsa_request_status of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_request_status

    @vpsa_request_status.setter
    def vpsa_request_status(self, vpsa_request_status):
        """Sets the vpsa_request_status of this InlineResponse200193Response.


        :param vpsa_request_status: The vpsa_request_status of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._vpsa_request_status = vpsa_request_status

    @property
    def pool_types_count(self):
        """Gets the pool_types_count of this InlineResponse200193Response.  # noqa: E501


        :return: The pool_types_count of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._pool_types_count

    @pool_types_count.setter
    def pool_types_count(self, pool_types_count):
        """Sets the pool_types_count of this InlineResponse200193Response.


        :param pool_types_count: The pool_types_count of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._pool_types_count = pool_types_count

    @property
    def pool_types(self):
        """Gets the pool_types of this InlineResponse200193Response.  # noqa: E501


        :return: The pool_types of this InlineResponse200193Response.  # noqa: E501
        :rtype: list[str]
        """
        return self._pool_types

    @pool_types.setter
    def pool_types(self, pool_types):
        """Sets the pool_types of this InlineResponse200193Response.


        :param pool_types: The pool_types of this InlineResponse200193Response.  # noqa: E501
        :type: list[str]
        """

        self._pool_types = pool_types

    @property
    def smb_charset_count(self):
        """Gets the smb_charset_count of this InlineResponse200193Response.  # noqa: E501


        :return: The smb_charset_count of this InlineResponse200193Response.  # noqa: E501
        :rtype: int
        """
        return self._smb_charset_count

    @smb_charset_count.setter
    def smb_charset_count(self, smb_charset_count):
        """Sets the smb_charset_count of this InlineResponse200193Response.


        :param smb_charset_count: The smb_charset_count of this InlineResponse200193Response.  # noqa: E501
        :type: int
        """

        self._smb_charset_count = smb_charset_count

    @property
    def smb_charsets(self):
        """Gets the smb_charsets of this InlineResponse200193Response.  # noqa: E501


        :return: The smb_charsets of this InlineResponse200193Response.  # noqa: E501
        :rtype: list[str]
        """
        return self._smb_charsets

    @smb_charsets.setter
    def smb_charsets(self, smb_charsets):
        """Sets the smb_charsets of this InlineResponse200193Response.


        :param smb_charsets: The smb_charsets of this InlineResponse200193Response.  # noqa: E501
        :type: list[str]
        """

        self._smb_charsets = smb_charsets

    @property
    def admin_access_enabled(self):
        """Gets the admin_access_enabled of this InlineResponse200193Response.  # noqa: E501


        :return: The admin_access_enabled of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._admin_access_enabled

    @admin_access_enabled.setter
    def admin_access_enabled(self, admin_access_enabled):
        """Sets the admin_access_enabled of this InlineResponse200193Response.


        :param admin_access_enabled: The admin_access_enabled of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._admin_access_enabled = admin_access_enabled

    @property
    def is_support_privilege_access_enabled(self):
        """Gets the is_support_privilege_access_enabled of this InlineResponse200193Response.  # noqa: E501


        :return: The is_support_privilege_access_enabled of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._is_support_privilege_access_enabled

    @is_support_privilege_access_enabled.setter
    def is_support_privilege_access_enabled(self, is_support_privilege_access_enabled):
        """Sets the is_support_privilege_access_enabled of this InlineResponse200193Response.


        :param is_support_privilege_access_enabled: The is_support_privilege_access_enabled of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._is_support_privilege_access_enabled = is_support_privilege_access_enabled

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200193Response.  # noqa: E501


        :return: The created_at of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200193Response.


        :param created_at: The created_at of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200193Response.  # noqa: E501


        :return: The modified_at of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200193Response.


        :param modified_at: The modified_at of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def service_mode(self):
        """Gets the service_mode of this InlineResponse200193Response.  # noqa: E501


        :return: The service_mode of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._service_mode

    @service_mode.setter
    def service_mode(self, service_mode):
        """Sets the service_mode of this InlineResponse200193Response.


        :param service_mode: The service_mode of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._service_mode = service_mode

    @property
    def expire_password(self):
        """Gets the expire_password of this InlineResponse200193Response.  # noqa: E501


        :return: The expire_password of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._expire_password

    @expire_password.setter
    def expire_password(self, expire_password):
        """Sets the expire_password of this InlineResponse200193Response.


        :param expire_password: The expire_password of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._expire_password = expire_password

    @property
    def expire_password_after(self):
        """Gets the expire_password_after of this InlineResponse200193Response.  # noqa: E501


        :return: The expire_password_after of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._expire_password_after

    @expire_password_after.setter
    def expire_password_after(self, expire_password_after):
        """Sets the expire_password_after of this InlineResponse200193Response.


        :param expire_password_after: The expire_password_after of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._expire_password_after = expire_password_after

    @property
    def min_password_length(self):
        """Gets the min_password_length of this InlineResponse200193Response.  # noqa: E501


        :return: The min_password_length of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._min_password_length

    @min_password_length.setter
    def min_password_length(self, min_password_length):
        """Sets the min_password_length of this InlineResponse200193Response.


        :param min_password_length: The min_password_length of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._min_password_length = min_password_length

    @property
    def password_must_contain_letters(self):
        """Gets the password_must_contain_letters of this InlineResponse200193Response.  # noqa: E501


        :return: The password_must_contain_letters of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._password_must_contain_letters

    @password_must_contain_letters.setter
    def password_must_contain_letters(self, password_must_contain_letters):
        """Sets the password_must_contain_letters of this InlineResponse200193Response.


        :param password_must_contain_letters: The password_must_contain_letters of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._password_must_contain_letters = password_must_contain_letters

    @property
    def password_must_contain_numbers(self):
        """Gets the password_must_contain_numbers of this InlineResponse200193Response.  # noqa: E501


        :return: The password_must_contain_numbers of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._password_must_contain_numbers

    @password_must_contain_numbers.setter
    def password_must_contain_numbers(self, password_must_contain_numbers):
        """Sets the password_must_contain_numbers of this InlineResponse200193Response.


        :param password_must_contain_numbers: The password_must_contain_numbers of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._password_must_contain_numbers = password_must_contain_numbers

    @property
    def password_must_contain_uppercase_letters(self):
        """Gets the password_must_contain_uppercase_letters of this InlineResponse200193Response.  # noqa: E501


        :return: The password_must_contain_uppercase_letters of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._password_must_contain_uppercase_letters

    @password_must_contain_uppercase_letters.setter
    def password_must_contain_uppercase_letters(self, password_must_contain_uppercase_letters):
        """Sets the password_must_contain_uppercase_letters of this InlineResponse200193Response.


        :param password_must_contain_uppercase_letters: The password_must_contain_uppercase_letters of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._password_must_contain_uppercase_letters = password_must_contain_uppercase_letters

    @property
    def password_must_contain_special_characters(self):
        """Gets the password_must_contain_special_characters of this InlineResponse200193Response.  # noqa: E501


        :return: The password_must_contain_special_characters of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._password_must_contain_special_characters

    @password_must_contain_special_characters.setter
    def password_must_contain_special_characters(self, password_must_contain_special_characters):
        """Sets the password_must_contain_special_characters of this InlineResponse200193Response.


        :param password_must_contain_special_characters: The password_must_contain_special_characters of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._password_must_contain_special_characters = password_must_contain_special_characters

    @property
    def password_requirements_text(self):
        """Gets the password_requirements_text of this InlineResponse200193Response.  # noqa: E501


        :return: The password_requirements_text of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._password_requirements_text

    @password_requirements_text.setter
    def password_requirements_text(self, password_requirements_text):
        """Sets the password_requirements_text of this InlineResponse200193Response.


        :param password_requirements_text: The password_requirements_text of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._password_requirements_text = password_requirements_text

    @property
    def password_history(self):
        """Gets the password_history of this InlineResponse200193Response.  # noqa: E501


        :return: The password_history of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._password_history

    @password_history.setter
    def password_history(self, password_history):
        """Sets the password_history of this InlineResponse200193Response.


        :param password_history: The password_history of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._password_history = password_history

    @property
    def legacy_otp_secret(self):
        """Gets the legacy_otp_secret of this InlineResponse200193Response.  # noqa: E501


        :return: The legacy_otp_secret of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._legacy_otp_secret

    @legacy_otp_secret.setter
    def legacy_otp_secret(self, legacy_otp_secret):
        """Sets the legacy_otp_secret of this InlineResponse200193Response.


        :param legacy_otp_secret: The legacy_otp_secret of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._legacy_otp_secret = legacy_otp_secret

    @property
    def vpsa_chap_user(self):
        """Gets the vpsa_chap_user of this InlineResponse200193Response.  # noqa: E501


        :return: The vpsa_chap_user of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_chap_user

    @vpsa_chap_user.setter
    def vpsa_chap_user(self, vpsa_chap_user):
        """Sets the vpsa_chap_user of this InlineResponse200193Response.


        :param vpsa_chap_user: The vpsa_chap_user of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._vpsa_chap_user = vpsa_chap_user

    @property
    def vpsa_chap_secret(self):
        """Gets the vpsa_chap_secret of this InlineResponse200193Response.  # noqa: E501


        :return: The vpsa_chap_secret of this InlineResponse200193Response.  # noqa: E501
        :rtype: str
        """
        return self._vpsa_chap_secret

    @vpsa_chap_secret.setter
    def vpsa_chap_secret(self, vpsa_chap_secret):
        """Sets the vpsa_chap_secret of this InlineResponse200193Response.


        :param vpsa_chap_secret: The vpsa_chap_secret of this InlineResponse200193Response.  # noqa: E501
        :type: str
        """

        self._vpsa_chap_secret = vpsa_chap_secret

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200193Response, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200193Response):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200193Response):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class CreateRemoteClone(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'displayname': 'str',
        'volname': 'str',
        'poolname': 'str',
        'remote_clone_mode': 'str',
        'vpsaname': 'str',
        'snapname': 'str',
        'dedupe': 'str',
        'compress': 'str',
        'encrypted': 'str'
    }

    attribute_map = {
        'displayname': 'displayname',
        'volname': 'volname',
        'poolname': 'poolname',
        'remote_clone_mode': 'remote_clone_mode',
        'vpsaname': 'vpsaname',
        'snapname': 'snapname',
        'dedupe': 'dedupe',
        'compress': 'compress',
        'encrypted': 'encrypted'
    }

    def __init__(self, displayname=None, volname=None, poolname=None, remote_clone_mode=None, vpsaname=None, snapname=None, dedupe=None, compress=None, encrypted=None, _configuration=None):  # noqa: E501
        """CreateRemoteClone - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._displayname = None
        self._volname = None
        self._poolname = None
        self._remote_clone_mode = None
        self._vpsaname = None
        self._snapname = None
        self._dedupe = None
        self._compress = None
        self._encrypted = None
        self.discriminator = None

        self.displayname = displayname
        self.volname = volname
        self.poolname = poolname
        self.remote_clone_mode = remote_clone_mode
        self.vpsaname = vpsaname
        self.snapname = snapname
        if dedupe is not None:
            self.dedupe = dedupe
        if compress is not None:
            self.compress = compress
        if encrypted is not None:
            self.encrypted = encrypted

    @property
    def displayname(self):
        """Gets the displayname of this CreateRemoteClone.  # noqa: E501

        The new remote clone name  # noqa: E501

        :return: The displayname of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._displayname

    @displayname.setter
    def displayname(self, displayname):
        """Sets the displayname of this CreateRemoteClone.

        The new remote clone name  # noqa: E501

        :param displayname: The displayname of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and displayname is None:
            raise ValueError("Invalid value for `displayname`, must not be `None`")  # noqa: E501

        self._displayname = displayname

    @property
    def volname(self):
        """Gets the volname of this CreateRemoteClone.  # noqa: E501

        Destination volume name  # noqa: E501

        :return: The volname of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._volname

    @volname.setter
    def volname(self, volname):
        """Sets the volname of this CreateRemoteClone.

        Destination volume name  # noqa: E501

        :param volname: The volname of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and volname is None:
            raise ValueError("Invalid value for `volname`, must not be `None`")  # noqa: E501

        self._volname = volname

    @property
    def poolname(self):
        """Gets the poolname of this CreateRemoteClone.  # noqa: E501

        Pool to create remote clone  # noqa: E501

        :return: The poolname of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._poolname

    @poolname.setter
    def poolname(self, poolname):
        """Sets the poolname of this CreateRemoteClone.

        Pool to create remote clone  # noqa: E501

        :param poolname: The poolname of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and poolname is None:
            raise ValueError("Invalid value for `poolname`, must not be `None`")  # noqa: E501

        self._poolname = poolname

    @property
    def remote_clone_mode(self):
        """Gets the remote_clone_mode of this CreateRemoteClone.  # noqa: E501

        Remote Clone mode  # noqa: E501

        :return: The remote_clone_mode of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._remote_clone_mode

    @remote_clone_mode.setter
    def remote_clone_mode(self, remote_clone_mode):
        """Sets the remote_clone_mode of this CreateRemoteClone.

        Remote Clone mode  # noqa: E501

        :param remote_clone_mode: The remote_clone_mode of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and remote_clone_mode is None:
            raise ValueError("Invalid value for `remote_clone_mode`, must not be `None`")  # noqa: E501
        allowed_values = ["clone", "retrieve"]  # noqa: E501
        if (self._configuration.client_side_validation and
                remote_clone_mode not in allowed_values):
            raise ValueError(
                "Invalid value for `remote_clone_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(remote_clone_mode, allowed_values)
            )

        self._remote_clone_mode = remote_clone_mode

    @property
    def vpsaname(self):
        """Gets the vpsaname of this CreateRemoteClone.  # noqa: E501

        The source vpsa name  # noqa: E501

        :return: The vpsaname of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._vpsaname

    @vpsaname.setter
    def vpsaname(self, vpsaname):
        """Sets the vpsaname of this CreateRemoteClone.

        The source vpsa name  # noqa: E501

        :param vpsaname: The vpsaname of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and vpsaname is None:
            raise ValueError("Invalid value for `vpsaname`, must not be `None`")  # noqa: E501

        self._vpsaname = vpsaname

    @property
    def snapname(self):
        """Gets the snapname of this CreateRemoteClone.  # noqa: E501

        The source snapshot name  # noqa: E501

        :return: The snapname of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._snapname

    @snapname.setter
    def snapname(self, snapname):
        """Sets the snapname of this CreateRemoteClone.

        The source snapshot name  # noqa: E501

        :param snapname: The snapname of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and snapname is None:
            raise ValueError("Invalid value for `snapname`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                snapname is not None and not re.search(r'^snap-[0-9a-f]{8}$', snapname)):  # noqa: E501
            raise ValueError(r"Invalid value for `snapname`, must be a follow pattern or equal to `/^snap-[0-9a-f]{8}$/`")  # noqa: E501

        self._snapname = snapname

    @property
    def dedupe(self):
        """Gets the dedupe of this CreateRemoteClone.  # noqa: E501

        Enable Dedupe For Remote Clone.  # noqa: E501

        :return: The dedupe of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._dedupe

    @dedupe.setter
    def dedupe(self, dedupe):
        """Sets the dedupe of this CreateRemoteClone.

        Enable Dedupe For Remote Clone.  # noqa: E501

        :param dedupe: The dedupe of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                dedupe not in allowed_values):
            raise ValueError(
                "Invalid value for `dedupe` ({0}), must be one of {1}"  # noqa: E501
                .format(dedupe, allowed_values)
            )

        self._dedupe = dedupe

    @property
    def compress(self):
        """Gets the compress of this CreateRemoteClone.  # noqa: E501

        Enable compress For Remote Clone.  # noqa: E501

        :return: The compress of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this CreateRemoteClone.

        Enable compress For Remote Clone.  # noqa: E501

        :param compress: The compress of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                compress not in allowed_values):
            raise ValueError(
                "Invalid value for `compress` ({0}), must be one of {1}"  # noqa: E501
                .format(compress, allowed_values)
            )

        self._compress = compress

    @property
    def encrypted(self):
        """Gets the encrypted of this CreateRemoteClone.  # noqa: E501

        Enable encryption for this Remote Clone.  # noqa: E501

        :return: The encrypted of this CreateRemoteClone.  # noqa: E501
        :rtype: str
        """
        return self._encrypted

    @encrypted.setter
    def encrypted(self, encrypted):
        """Sets the encrypted of this CreateRemoteClone.

        Enable encryption for this Remote Clone.  # noqa: E501

        :param encrypted: The encrypted of this CreateRemoteClone.  # noqa: E501
        :type: str
        """
        allowed_values = ["YES", "NO"]  # noqa: E501
        if (self._configuration.client_side_validation and
                encrypted not in allowed_values):
            raise ValueError(
                "Invalid value for `encrypted` ({0}), must be one of {1}"  # noqa: E501
                .format(encrypted, allowed_values)
            )

        self._encrypted = encrypted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateRemoteClone, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRemoteClone):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateRemoteClone):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20048Data(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'vpsa_id': 'int',
        'user_id': 'int',
        'account_name': 'str',
        'status': 'str',
        'zios_request_id': 'int',
        'used_capacity': 'float',
        'containers_count': 'int',
        'objects_count': 'int',
        'created_at': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'vpsa_id': 'vpsa_id',
        'user_id': 'user_id',
        'account_name': 'account_name',
        'status': 'status',
        'zios_request_id': 'zios_request_id',
        'used_capacity': 'used_capacity',
        'containers_count': 'containers_count',
        'objects_count': 'objects_count',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, vpsa_id=None, user_id=None, account_name=None, status=None, zios_request_id=None, used_capacity=None, containers_count=None, objects_count=None, created_at=None, updated_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20048Data - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._vpsa_id = None
        self._user_id = None
        self._account_name = None
        self._status = None
        self._zios_request_id = None
        self._used_capacity = None
        self._containers_count = None
        self._objects_count = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if vpsa_id is not None:
            self.vpsa_id = vpsa_id
        if user_id is not None:
            self.user_id = user_id
        if account_name is not None:
            self.account_name = account_name
        if status is not None:
            self.status = status
        if zios_request_id is not None:
            self.zios_request_id = zios_request_id
        if used_capacity is not None:
            self.used_capacity = used_capacity
        if containers_count is not None:
            self.containers_count = containers_count
        if objects_count is not None:
            self.objects_count = objects_count
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this InlineResponse20048Data.  # noqa: E501


        :return: The id of this InlineResponse20048Data.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20048Data.


        :param id: The id of this InlineResponse20048Data.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def vpsa_id(self):
        """Gets the vpsa_id of this InlineResponse20048Data.  # noqa: E501


        :return: The vpsa_id of this InlineResponse20048Data.  # noqa: E501
        :rtype: int
        """
        return self._vpsa_id

    @vpsa_id.setter
    def vpsa_id(self, vpsa_id):
        """Sets the vpsa_id of this InlineResponse20048Data.


        :param vpsa_id: The vpsa_id of this InlineResponse20048Data.  # noqa: E501
        :type: int
        """

        self._vpsa_id = vpsa_id

    @property
    def user_id(self):
        """Gets the user_id of this InlineResponse20048Data.  # noqa: E501


        :return: The user_id of this InlineResponse20048Data.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this InlineResponse20048Data.


        :param user_id: The user_id of this InlineResponse20048Data.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def account_name(self):
        """Gets the account_name of this InlineResponse20048Data.  # noqa: E501


        :return: The account_name of this InlineResponse20048Data.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this InlineResponse20048Data.


        :param account_name: The account_name of this InlineResponse20048Data.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def status(self):
        """Gets the status of this InlineResponse20048Data.  # noqa: E501


        :return: The status of this InlineResponse20048Data.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20048Data.


        :param status: The status of this InlineResponse20048Data.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def zios_request_id(self):
        """Gets the zios_request_id of this InlineResponse20048Data.  # noqa: E501


        :return: The zios_request_id of this InlineResponse20048Data.  # noqa: E501
        :rtype: int
        """
        return self._zios_request_id

    @zios_request_id.setter
    def zios_request_id(self, zios_request_id):
        """Sets the zios_request_id of this InlineResponse20048Data.


        :param zios_request_id: The zios_request_id of this InlineResponse20048Data.  # noqa: E501
        :type: int
        """

        self._zios_request_id = zios_request_id

    @property
    def used_capacity(self):
        """Gets the used_capacity of this InlineResponse20048Data.  # noqa: E501


        :return: The used_capacity of this InlineResponse20048Data.  # noqa: E501
        :rtype: float
        """
        return self._used_capacity

    @used_capacity.setter
    def used_capacity(self, used_capacity):
        """Sets the used_capacity of this InlineResponse20048Data.


        :param used_capacity: The used_capacity of this InlineResponse20048Data.  # noqa: E501
        :type: float
        """

        self._used_capacity = used_capacity

    @property
    def containers_count(self):
        """Gets the containers_count of this InlineResponse20048Data.  # noqa: E501


        :return: The containers_count of this InlineResponse20048Data.  # noqa: E501
        :rtype: int
        """
        return self._containers_count

    @containers_count.setter
    def containers_count(self, containers_count):
        """Sets the containers_count of this InlineResponse20048Data.


        :param containers_count: The containers_count of this InlineResponse20048Data.  # noqa: E501
        :type: int
        """

        self._containers_count = containers_count

    @property
    def objects_count(self):
        """Gets the objects_count of this InlineResponse20048Data.  # noqa: E501


        :return: The objects_count of this InlineResponse20048Data.  # noqa: E501
        :rtype: int
        """
        return self._objects_count

    @objects_count.setter
    def objects_count(self, objects_count):
        """Sets the objects_count of this InlineResponse20048Data.


        :param objects_count: The objects_count of this InlineResponse20048Data.  # noqa: E501
        :type: int
        """

        self._objects_count = objects_count

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20048Data.  # noqa: E501


        :return: The created_at of this InlineResponse20048Data.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20048Data.


        :param created_at: The created_at of this InlineResponse20048Data.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this InlineResponse20048Data.  # noqa: E501


        :return: The updated_at of this InlineResponse20048Data.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this InlineResponse20048Data.


        :param updated_at: The updated_at of this InlineResponse20048Data.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20048Data, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20048Data):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20048Data):
            return True

        return self.to_dict() != other.to_dict()
